==> green-core-1.70.1.tgz: package/components/link/link.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet
} from "../../chunks/chunk.QTSIPXV3.js";
var _defaultRel, defaultRel_get;
import { unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { html as staticHtml } from "lit/static-html.js";
import { GdsElement } from "../../gds-element";
import { gdsCustomElement } from "../../scoping";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins";
import style from "./link.styles";
let GdsLink = class extends withMarginProps(
  withSizeXProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super();
    __privateAdd(this, _defaultRel);
    this.href = "";
  }
  render() {
    return staticHtml`
      <a
        href=${ifDefined(this.href)}
        target=${ifDefined(this.target)}
        rel=${ifDefined(this.rel || __privateGet(this, _defaultRel, defaultRel_get))}
        download=${ifDefined(this.download)}
      >
        <slot name="lead"></slot>
        <slot></slot>
        <slot name="trail"></slot>
      </a>
    `;
  }
};
_defaultRel = new WeakSet();
defaultRel_get = function() {
  return this.target === "_blank" ? "noreferrer noopener" : void 0;
};
GdsLink.styles = [tokens, unsafeCSS(style)];
GdsLink.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property()
], GdsLink.prototype, "href", 2);
__decorateClass([
  property()
], GdsLink.prototype, "target", 2);
__decorateClass([
  property()
], GdsLink.prototype, "rel", 2);
__decorateClass([
  property()
], GdsLink.prototype, "download", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: "a"
  })
], GdsLink.prototype, "text-decoration", 2);
GdsLink = __decorateClass([
  gdsCustomElement("gds-link")
], GdsLink);
export {
  GdsLink
};

==> green-core-1.71.0.tgz: package/components/link/link.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet
} from "../../chunks/chunk.QTSIPXV3.js";
var _defaultRel, defaultRel_get;
import { unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { html as staticHtml } from "lit/static-html.js";
import { GdsElement } from "../../gds-element.js";
import { gdsCustomElement } from "../../scoping.js";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import style from "./link.styles";
let GdsLink = class extends withMarginProps(
  withSizeXProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super();
    __privateAdd(this, _defaultRel);
    this.href = "";
  }
  render() {
    return staticHtml`
      <a
        href=${ifDefined(this.href)}
        target=${ifDefined(this.target)}
        rel=${ifDefined(this.rel || __privateGet(this, _defaultRel, defaultRel_get))}
        download=${ifDefined(this.download)}
      >
        <slot name="lead"></slot>
        <slot></slot>
        <slot name="trail"></slot>
      </a>
    `;
  }
};
_defaultRel = new WeakSet();
defaultRel_get = function() {
  return this.target === "_blank" ? "noreferrer noopener" : void 0;
};
GdsLink.styles = [tokens, unsafeCSS(style)];
GdsLink.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property()
], GdsLink.prototype, "href", 2);
__decorateClass([
  property()
], GdsLink.prototype, "target", 2);
__decorateClass([
  property()
], GdsLink.prototype, "rel", 2);
__decorateClass([
  property()
], GdsLink.prototype, "download", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: "a"
  })
], GdsLink.prototype, "text-decoration", 2);
GdsLink = __decorateClass([
  gdsCustomElement("gds-link")
], GdsLink);
export {
  GdsLink
};
